@@ -65,7 +65,6 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(bool canExecute READ canExecute CONSTANT)
     Q_PROPERTY(State state READ state NOTIFY stateChanged)
     Q_PROPERTY(QString status READ status NOTIFY stateChanged)
-    Q_PROPERTY(QStringList category READ categories CONSTANT)
     Q_PROPERTY(QUrl homepage READ homepage CONSTANT)
     Q_PROPERTY(QUrl helpURL READ helpURL CONSTANT)
     Q_PROPERTY(QUrl bugURL READ bugURL CONSTANT)
@@ -98,6 +97,8 @@ class DISCOVERCOMMON_EXPORT AbstractResource : public QObject
     Q_PROPERTY(uint contentRatingMinimumAge READ contentRatingMinimumAge CONSTANT)
     Q_PROPERTY(QStringList topObjects READ topObjects CONSTANT)
     Q_PROPERTY(QStringList bottomObjects READ bottomObjects CONSTANT)
+    Q_PROPERTY(QString verifiedMessage READ verifiedMessage CONSTANT)
+    Q_PROPERTY(QString verifiedIconName READ verifiedIconName CONSTANT)
     Q_PROPERTY(Type type READ type CONSTANT)
 
     // Resolve circular dependency for QObject* properties in both classes
@@ -154,7 +155,7 @@ public:
 
     virtual State state() = 0;
 
-    virtual QStringList categories() = 0;
+    virtual bool hasCategory(const QString &category) const = 0;
     ///@returns a URL that points to the app's website
     virtual QUrl homepage();
     ///@returns a URL that points to the app's online documentation
@@ -276,6 +277,31 @@ public:
     [[nodiscard]] virtual bool hasResolvedIcon() const;
     virtual void resolveIcon();
 
+    /**
+     * @returns whether the verification message of the resource
+     *
+     * Normally app stores will have extra trust checks on certain assets.
+     * If the string is empty it means that the asset isn't verified.
+     * The text will contain the explanation of what the verification entails.
+     */
+    virtual QString verifiedMessage() const
+    {
+        return {};
+    }
+
+    /**
+     * @returns the icon name of the verification badge appropriate to the verification
+     */
+    virtual QString verifiedIconName() const
+    {
+        return QStringLiteral("checkmark");
+    }
+
+    virtual bool updateNeedsAttention()
+    {
+        return false;
+    }
+
 public Q_SLOTS:
     virtual void fetchScreenshots();
     virtual void fetchChangelog() = 0;
