@@ -4,8 +4,7 @@
  *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
 
-#ifndef RESOURCESUPDATESMODEL_H
-#define RESOURCESUPDATESMODEL_H
+#pragma once
 
 #include "discovercommon_export.h"
 #include "resources/AbstractBackendUpdater.h"
@@ -28,6 +27,8 @@ class DISCOVERCOMMON_EXPORT ResourcesUpdatesModel : public QStandardItemModel
     Q_PROPERTY(bool readyToReboot READ readyToReboot)
     Q_PROPERTY(bool useUnattendedUpdates READ useUnattendedUpdates NOTIFY useUnattendedUpdatesChanged)
     Q_PROPERTY(QStringList errorMessages READ errorMessages NOTIFY errorMessagesChanged)
+
+    Q_MOC_INCLUDE("Transaction/Transaction.h")
 public:
     explicit ResourcesUpdatesModel(QObject *parent = nullptr);
 
@@ -80,5 +81,3 @@ private:
     QPointer<UpdateTransaction> m_transaction;
     QStringList m_errorMessages;
 };
-
-#endif // RESOURCESUPDATESMODEL_H
